@@ -7,7 +7,7 @@
 # the same terms as the Perl 5 programming language system itself.
 # 
 package Dist::Zilla::Plugin::CompileTests;
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 # ABSTRACT: common tests to check syntax of your modules
 
@@ -31,7 +31,7 @@ Dist::Zilla::Plugin::CompileTests - common tests to check syntax of your modules
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
@@ -80,24 +80,27 @@ ___[ t/00-compile.t ]___
 use strict;
 use warnings;
 
-use File::Find::Rule;
 use Test::More;
-use Test::Script;
+use File::Find::Rule;
 
 my @modules = File::Find::Rule->relative->file->name('*.pm')->in('lib');
 my @scripts = glob "bin/*";
 
 plan tests => scalar(@modules) + scalar(@scripts);
-
+    
 foreach my $file ( @modules ) {
     my $module = $file;
     $module =~ s/[\/\\]/::/g;
     $module =~ s/\.pm$//;
     is( qx{ $^X -M$module -e "print '$module ok'" }, "$module ok", "$module loaded ok" );
 }
-
-foreach my $file ( @scripts ) {
-    my $script = $file;
-    $script =~ s!.*/!!;
-    script_compiles_ok( $file, "$script script compiles" );
+    
+SKIP: {
+    eval "use Test::Script; 1;";
+    skip "Test::Script needed to test script compilation", scalar(@scripts) if $@;
+    foreach my $file ( @scripts ) {
+        my $script = $file;
+        $script =~ s!.*/!!;
+        script_compiles_ok( $file, "$script script compiles" );
+    }
 }
\ No newline at end of file
